# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: markets.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .github.com.mwitkow.go_proto_validators import validator_pb2 as github_dot_com_dot_mwitkow_dot_go__proto__validators_dot_validator__pb2
from .oracles.v1 import oracle_spec_pb2 as oracles_dot_v1_dot_oracle__spec__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='markets.proto',
  package='vega',
  syntax='proto3',
  serialized_options=b'\n\024io.vegaprotocol.vegaZ\037code.vegaprotocol.io/vega/proto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rmarkets.proto\x12\x04vega\x1a\x36github.com/mwitkow/go-proto-validators/validator.proto\x1a\x1coracles/v1/oracle_spec.proto\"E\n\x0f\x41uctionDuration\x12\x1a\n\x08\x64uration\x18\x01 \x01(\x03R\x08\x64uration\x12\x16\n\x06volume\x18\x02 \x01(\x04R\x06volume\"0\n\x11\x43ontinuousTrading\x12\x1b\n\ttick_size\x18\x01 \x01(\tR\x08tickSize\"`\n\x0f\x44iscreteTrading\x12\x30\n\x0b\x64uration_ns\x18\x01 \x01(\x03\x42\x0f\xe2\xdf\x1f\x0b\x10\x00\x18\x80\x80\x88\xba\x90\xad\xcd\x04R\ndurationNs\x12\x1b\n\ttick_size\x18\x02 \x01(\tR\x08tickSize\"\xf8\x01\n\x06\x46uture\x12\x1a\n\x08maturity\x18\x01 \x01(\tR\x08maturity\x12)\n\x10settlement_asset\x18\x02 \x01(\tR\x0fsettlementAsset\x12\x1d\n\nquote_name\x18\x04 \x01(\tR\tquoteName\x12\x37\n\x0boracle_spec\x18\x05 \x01(\x0b\x32\x16.oracles.v1.OracleSpecR\noracleSpec\x12O\n\x13oracle_spec_binding\x18\x06 \x01(\x0b\x32\x1f.vega.OracleSpecToFutureBindingR\x11oracleSpecBinding\"W\n\x19OracleSpecToFutureBinding\x12:\n\x19settlement_price_property\x18\x01 \x01(\tR\x17settlementPriceProperty\"(\n\x12InstrumentMetadata\x12\x12\n\x04tags\x18\x01 \x03(\tR\x04tags\"\xad\x01\n\nInstrument\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04\x63ode\x18\x02 \x01(\tR\x04\x63ode\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x34\n\x08metadata\x18\x04 \x01(\x0b\x32\x18.vega.InstrumentMetadataR\x08metadata\x12&\n\x06\x66uture\x18\x64 \x01(\x0b\x32\x0c.vega.FutureH\x00R\x06\x66utureB\t\n\x07product\"\x92\x01\n\x12LogNormalRiskModel\x12\x36\n\x17risk_aversion_parameter\x18\x01 \x01(\x01R\x15riskAversionParameter\x12\x10\n\x03tau\x18\x02 \x01(\x01R\x03tau\x12\x32\n\x06params\x18\x03 \x01(\x0b\x32\x1a.vega.LogNormalModelParamsR\x06params\"J\n\x14LogNormalModelParams\x12\x0e\n\x02mu\x18\x01 \x01(\x01R\x02mu\x12\x0c\n\x01r\x18\x02 \x01(\x01R\x01r\x12\x14\n\x05sigma\x18\x03 \x01(\x01R\x05sigma\"B\n\x0fSimpleRiskModel\x12/\n\x06params\x18\x01 \x01(\x0b\x32\x17.vega.SimpleModelParamsR\x06params\"\x87\x02\n\x11SimpleModelParams\x12\x1f\n\x0b\x66\x61\x63tor_long\x18\x01 \x01(\x01R\nfactorLong\x12!\n\x0c\x66\x61\x63tor_short\x18\x02 \x01(\x01R\x0b\x66\x61\x63torShort\x12-\n\x0bmax_move_up\x18\x03 \x01(\x01\x42\r\xe2\xdf\x1f\tI\x00\x00\x00\x00\x00\x00\x00\x00R\tmaxMoveUp\x12\x31\n\rmin_move_down\x18\x04 \x01(\x01\x42\r\xe2\xdf\x1f\tQ\x00\x00\x00\x00\x00\x00\x00\x00R\x0bminMoveDown\x12L\n\x16probability_of_trading\x18\x05 \x01(\x01\x42\x16\xe2\xdf\x1f\x12I\x00\x00\x00\x00\x00\x00\x00\x00Q\x00\x00\x00\x00\x00\x00\xf0?R\x14probabilityOfTrading\"\x89\x01\n\x0eScalingFactors\x12!\n\x0csearch_level\x18\x01 \x01(\x01R\x0bsearchLevel\x12%\n\x0einitial_margin\x18\x02 \x01(\x01R\rinitialMargin\x12-\n\x12\x63ollateral_release\x18\x03 \x01(\x01R\x11\x63ollateralRelease\"Q\n\x10MarginCalculator\x12=\n\x0fscaling_factors\x18\x01 \x01(\x0b\x32\x14.vega.ScalingFactorsR\x0escalingFactors\"\xad\x02\n\x12TradableInstrument\x12\x30\n\ninstrument\x18\x01 \x01(\x0b\x32\x10.vega.InstrumentR\ninstrument\x12\x43\n\x11margin_calculator\x18\x02 \x01(\x0b\x32\x16.vega.MarginCalculatorR\x10marginCalculator\x12M\n\x15log_normal_risk_model\x18\x64 \x01(\x0b\x32\x18.vega.LogNormalRiskModelH\x00R\x12logNormalRiskModel\x12\x43\n\x11simple_risk_model\x18\x65 \x01(\x0b\x32\x15.vega.SimpleRiskModelH\x00R\x0fsimpleRiskModelB\x0c\n\nrisk_model\"}\n\nFeeFactors\x12\x1b\n\tmaker_fee\x18\x01 \x01(\tR\x08makerFee\x12-\n\x12infrastructure_fee\x18\x02 \x01(\tR\x11infrastructureFee\x12#\n\rliquidity_fee\x18\x03 \x01(\tR\x0cliquidityFee\"2\n\x04\x46\x65\x65s\x12*\n\x07\x66\x61\x63tors\x18\x01 \x01(\x0b\x32\x10.vega.FeeFactorsR\x07\x66\x61\x63tors\"\xa9\x01\n\x16PriceMonitoringTrigger\x12 \n\x07horizon\x18\x01 \x01(\x03\x42\x06\xe2\xdf\x1f\x02\x10\x00R\x07horizon\x12\x38\n\x0bprobability\x18\x02 \x01(\x01\x42\x16\xe2\xdf\x1f\x12\x31\x00\x00\x00\x00\x00\x00\x00\x00\x39\x00\x00\x00\x00\x00\x00\xf0?R\x0bprobability\x12\x33\n\x11\x61uction_extension\x18\x03 \x01(\x03\x42\x06\xe2\xdf\x1f\x02\x10\x00R\x10\x61uctionExtension\"U\n\x19PriceMonitoringParameters\x12\x38\n\x08triggers\x18\x01 \x03(\x0b\x32\x1c.vega.PriceMonitoringTriggerR\x08triggers\"\x85\x01\n\x17PriceMonitoringSettings\x12?\n\nparameters\x18\x01 \x01(\x0b\x32\x1f.vega.PriceMonitoringParametersR\nparameters\x12)\n\x10update_frequency\x18\x02 \x01(\x03R\x0fupdateFrequency\"\xe4\x01\n\x1dLiquidityMonitoringParameters\x12S\n\x17target_stake_parameters\x18\x01 \x01(\x0b\x32\x1b.vega.TargetStakeParametersR\x15targetStakeParameters\x12\x41\n\x10triggering_ratio\x18\x02 \x01(\x01\x42\x16\xe2\xdf\x1f\x12I\x00\x00\x00\x00\x00\x00\x00\x00Q\x00\x00\x00\x00\x00\x00\xf0?R\x0ftriggeringRatio\x12+\n\x11\x61uction_extension\x18\x03 \x01(\x03R\x10\x61uctionExtension\"v\n\x15TargetStakeParameters\x12\'\n\x0btime_window\x18\x01 \x01(\x03\x42\x06\xe2\xdf\x1f\x02\x10\x00R\ntimeWindow\x12\x34\n\x0escaling_factor\x18\x02 \x01(\x01\x42\r\xe2\xdf\x1f\t1\x00\x00\x00\x00\x00\x00\x00\x00R\rscalingFactor\"\xf2\x08\n\x06Market\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12I\n\x13tradable_instrument\x18\x02 \x01(\x0b\x32\x18.vega.TradableInstrumentR\x12tradableInstrument\x12%\n\x0e\x64\x65\x63imal_places\x18\x03 \x01(\x04R\rdecimalPlaces\x12\x1e\n\x04\x66\x65\x65s\x18\x04 \x01(\x0b\x32\n.vega.FeesR\x04\x66\x65\x65s\x12>\n\x0fopening_auction\x18\x05 \x01(\x0b\x32\x15.vega.AuctionDurationR\x0eopeningAuction\x12\x39\n\ncontinuous\x18\x64 \x01(\x0b\x32\x17.vega.ContinuousTradingH\x00R\ncontinuous\x12\x33\n\x08\x64iscrete\x18\x65 \x01(\x0b\x32\x15.vega.DiscreteTradingH\x00R\x08\x64iscrete\x12Y\n\x19price_monitoring_settings\x18\x06 \x01(\x0b\x32\x1d.vega.PriceMonitoringSettingsR\x17priceMonitoringSettings\x12k\n\x1fliquidity_monitoring_parameters\x18\x07 \x01(\x0b\x32#.vega.LiquidityMonitoringParametersR\x1dliquidityMonitoringParameters\x12;\n\x0ctrading_mode\x18\x08 \x01(\x0e\x32\x18.vega.Market.TradingModeR\x0btradingMode\x12(\n\x05state\x18\t \x01(\x0e\x32\x12.vega.Market.StateR\x05state\x12\x43\n\x11market_timestamps\x18\n \x01(\x0b\x32\x16.vega.MarketTimestampsR\x10marketTimestamps\"\xd8\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x12\n\x0eSTATE_PROPOSED\x10\x01\x12\x12\n\x0eSTATE_REJECTED\x10\x02\x12\x11\n\rSTATE_PENDING\x10\x03\x12\x13\n\x0fSTATE_CANCELLED\x10\x04\x12\x10\n\x0cSTATE_ACTIVE\x10\x05\x12\x13\n\x0fSTATE_SUSPENDED\x10\x06\x12\x10\n\x0cSTATE_CLOSED\x10\x07\x12\x1c\n\x18STATE_TRADING_TERMINATED\x10\x08\x12\x11\n\rSTATE_SETTLED\x10\t\"\xaf\x01\n\x0bTradingMode\x12\x1c\n\x18TRADING_MODE_UNSPECIFIED\x10\x00\x12\x1b\n\x17TRADING_MODE_CONTINUOUS\x10\x01\x12\x1e\n\x1aTRADING_MODE_BATCH_AUCTION\x10\x02\x12 \n\x1cTRADING_MODE_OPENING_AUCTION\x10\x03\x12#\n\x1fTRADING_MODE_MONITORING_AUCTION\x10\x04\x42\x15\n\x13trading_mode_config\"r\n\x10MarketTimestamps\x12\x1a\n\x08proposed\x18\x01 \x01(\x03R\x08proposed\x12\x18\n\x07pending\x18\x02 \x01(\x03R\x07pending\x12\x12\n\x04open\x18\x03 \x01(\x03R\x04open\x12\x14\n\x05\x63lose\x18\x04 \x01(\x03R\x05\x63loseB7\n\x14io.vegaprotocol.vegaZ\x1f\x63ode.vegaprotocol.io/vega/protob\x06proto3'
  ,
  dependencies=[github_dot_com_dot_mwitkow_dot_go__proto__validators_dot_validator__pb2.DESCRIPTOR,oracles_dot_v1_dot_oracle__spec__pb2.DESCRIPTOR,])



_MARKET_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='vega.Market.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_PROPOSED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_REJECTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_PENDING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_CANCELLED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_ACTIVE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_SUSPENDED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_CLOSED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_TRADING_TERMINATED', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_SETTLED', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3619,
  serialized_end=3835,
)
_sym_db.RegisterEnumDescriptor(_MARKET_STATE)

_MARKET_TRADINGMODE = _descriptor.EnumDescriptor(
  name='TradingMode',
  full_name='vega.Market.TradingMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRADING_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRADING_MODE_CONTINUOUS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRADING_MODE_BATCH_AUCTION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRADING_MODE_OPENING_AUCTION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRADING_MODE_MONITORING_AUCTION', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3838,
  serialized_end=4013,
)
_sym_db.RegisterEnumDescriptor(_MARKET_TRADINGMODE)


_AUCTIONDURATION = _descriptor.Descriptor(
  name='AuctionDuration',
  full_name='vega.AuctionDuration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration', full_name='vega.AuctionDuration.duration', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='duration', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='vega.AuctionDuration.volume', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='volume', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=178,
)


_CONTINUOUSTRADING = _descriptor.Descriptor(
  name='ContinuousTrading',
  full_name='vega.ContinuousTrading',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_size', full_name='vega.ContinuousTrading.tick_size', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tickSize', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=180,
  serialized_end=228,
)


_DISCRETETRADING = _descriptor.Descriptor(
  name='DiscreteTrading',
  full_name='vega.DiscreteTrading',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration_ns', full_name='vega.DiscreteTrading.duration_ns', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\013\020\000\030\200\200\210\272\220\255\315\004', json_name='durationNs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_size', full_name='vega.DiscreteTrading.tick_size', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tickSize', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=326,
)


_FUTURE = _descriptor.Descriptor(
  name='Future',
  full_name='vega.Future',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='maturity', full_name='vega.Future.maturity', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maturity', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settlement_asset', full_name='vega.Future.settlement_asset', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='settlementAsset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_name', full_name='vega.Future.quote_name', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='quoteName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_spec', full_name='vega.Future.oracle_spec', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='oracleSpec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_spec_binding', full_name='vega.Future.oracle_spec_binding', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='oracleSpecBinding', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=329,
  serialized_end=577,
)


_ORACLESPECTOFUTUREBINDING = _descriptor.Descriptor(
  name='OracleSpecToFutureBinding',
  full_name='vega.OracleSpecToFutureBinding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='settlement_price_property', full_name='vega.OracleSpecToFutureBinding.settlement_price_property', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='settlementPriceProperty', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=579,
  serialized_end=666,
)


_INSTRUMENTMETADATA = _descriptor.Descriptor(
  name='InstrumentMetadata',
  full_name='vega.InstrumentMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tags', full_name='vega.InstrumentMetadata.tags', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tags', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=668,
  serialized_end=708,
)


_INSTRUMENT = _descriptor.Descriptor(
  name='Instrument',
  full_name='vega.Instrument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='vega.Instrument.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='vega.Instrument.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='code', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='vega.Instrument.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='vega.Instrument.metadata', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='future', full_name='vega.Instrument.future', index=4,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='future', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='product', full_name='vega.Instrument.product',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=711,
  serialized_end=884,
)


_LOGNORMALRISKMODEL = _descriptor.Descriptor(
  name='LogNormalRiskModel',
  full_name='vega.LogNormalRiskModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='risk_aversion_parameter', full_name='vega.LogNormalRiskModel.risk_aversion_parameter', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='riskAversionParameter', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tau', full_name='vega.LogNormalRiskModel.tau', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tau', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='vega.LogNormalRiskModel.params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='params', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=887,
  serialized_end=1033,
)


_LOGNORMALMODELPARAMS = _descriptor.Descriptor(
  name='LogNormalModelParams',
  full_name='vega.LogNormalModelParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mu', full_name='vega.LogNormalModelParams.mu', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='mu', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='r', full_name='vega.LogNormalModelParams.r', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='r', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sigma', full_name='vega.LogNormalModelParams.sigma', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sigma', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1035,
  serialized_end=1109,
)


_SIMPLERISKMODEL = _descriptor.Descriptor(
  name='SimpleRiskModel',
  full_name='vega.SimpleRiskModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='vega.SimpleRiskModel.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='params', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1111,
  serialized_end=1177,
)


_SIMPLEMODELPARAMS = _descriptor.Descriptor(
  name='SimpleModelParams',
  full_name='vega.SimpleModelParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='factor_long', full_name='vega.SimpleModelParams.factor_long', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='factorLong', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='factor_short', full_name='vega.SimpleModelParams.factor_short', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='factorShort', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_move_up', full_name='vega.SimpleModelParams.max_move_up', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\tI\000\000\000\000\000\000\000\000', json_name='maxMoveUp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_move_down', full_name='vega.SimpleModelParams.min_move_down', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\tQ\000\000\000\000\000\000\000\000', json_name='minMoveDown', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='probability_of_trading', full_name='vega.SimpleModelParams.probability_of_trading', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\022I\000\000\000\000\000\000\000\000Q\000\000\000\000\000\000\360?', json_name='probabilityOfTrading', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1180,
  serialized_end=1443,
)


_SCALINGFACTORS = _descriptor.Descriptor(
  name='ScalingFactors',
  full_name='vega.ScalingFactors',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_level', full_name='vega.ScalingFactors.search_level', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='searchLevel', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_margin', full_name='vega.ScalingFactors.initial_margin', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='initialMargin', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collateral_release', full_name='vega.ScalingFactors.collateral_release', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='collateralRelease', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1446,
  serialized_end=1583,
)


_MARGINCALCULATOR = _descriptor.Descriptor(
  name='MarginCalculator',
  full_name='vega.MarginCalculator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scaling_factors', full_name='vega.MarginCalculator.scaling_factors', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='scalingFactors', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1585,
  serialized_end=1666,
)


_TRADABLEINSTRUMENT = _descriptor.Descriptor(
  name='TradableInstrument',
  full_name='vega.TradableInstrument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instrument', full_name='vega.TradableInstrument.instrument', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='instrument', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='margin_calculator', full_name='vega.TradableInstrument.margin_calculator', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='marginCalculator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_normal_risk_model', full_name='vega.TradableInstrument.log_normal_risk_model', index=2,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='logNormalRiskModel', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simple_risk_model', full_name='vega.TradableInstrument.simple_risk_model', index=3,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='simpleRiskModel', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='risk_model', full_name='vega.TradableInstrument.risk_model',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1669,
  serialized_end=1970,
)


_FEEFACTORS = _descriptor.Descriptor(
  name='FeeFactors',
  full_name='vega.FeeFactors',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='maker_fee', full_name='vega.FeeFactors.maker_fee', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='makerFee', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='infrastructure_fee', full_name='vega.FeeFactors.infrastructure_fee', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='infrastructureFee', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='liquidity_fee', full_name='vega.FeeFactors.liquidity_fee', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='liquidityFee', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1972,
  serialized_end=2097,
)


_FEES = _descriptor.Descriptor(
  name='Fees',
  full_name='vega.Fees',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='factors', full_name='vega.Fees.factors', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='factors', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2099,
  serialized_end=2149,
)


_PRICEMONITORINGTRIGGER = _descriptor.Descriptor(
  name='PriceMonitoringTrigger',
  full_name='vega.PriceMonitoringTrigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='horizon', full_name='vega.PriceMonitoringTrigger.horizon', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002\020\000', json_name='horizon', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='probability', full_name='vega.PriceMonitoringTrigger.probability', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\0221\000\000\000\000\000\000\000\0009\000\000\000\000\000\000\360?', json_name='probability', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auction_extension', full_name='vega.PriceMonitoringTrigger.auction_extension', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002\020\000', json_name='auctionExtension', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2152,
  serialized_end=2321,
)


_PRICEMONITORINGPARAMETERS = _descriptor.Descriptor(
  name='PriceMonitoringParameters',
  full_name='vega.PriceMonitoringParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='triggers', full_name='vega.PriceMonitoringParameters.triggers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='triggers', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2323,
  serialized_end=2408,
)


_PRICEMONITORINGSETTINGS = _descriptor.Descriptor(
  name='PriceMonitoringSettings',
  full_name='vega.PriceMonitoringSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameters', full_name='vega.PriceMonitoringSettings.parameters', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='parameters', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_frequency', full_name='vega.PriceMonitoringSettings.update_frequency', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='updateFrequency', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2411,
  serialized_end=2544,
)


_LIQUIDITYMONITORINGPARAMETERS = _descriptor.Descriptor(
  name='LiquidityMonitoringParameters',
  full_name='vega.LiquidityMonitoringParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_stake_parameters', full_name='vega.LiquidityMonitoringParameters.target_stake_parameters', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='targetStakeParameters', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='triggering_ratio', full_name='vega.LiquidityMonitoringParameters.triggering_ratio', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\022I\000\000\000\000\000\000\000\000Q\000\000\000\000\000\000\360?', json_name='triggeringRatio', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auction_extension', full_name='vega.LiquidityMonitoringParameters.auction_extension', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='auctionExtension', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2547,
  serialized_end=2775,
)


_TARGETSTAKEPARAMETERS = _descriptor.Descriptor(
  name='TargetStakeParameters',
  full_name='vega.TargetStakeParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_window', full_name='vega.TargetStakeParameters.time_window', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002\020\000', json_name='timeWindow', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scaling_factor', full_name='vega.TargetStakeParameters.scaling_factor', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\t1\000\000\000\000\000\000\000\000', json_name='scalingFactor', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2777,
  serialized_end=2895,
)


_MARKET = _descriptor.Descriptor(
  name='Market',
  full_name='vega.Market',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='vega.Market.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tradable_instrument', full_name='vega.Market.tradable_instrument', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tradableInstrument', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decimal_places', full_name='vega.Market.decimal_places', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='decimalPlaces', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fees', full_name='vega.Market.fees', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fees', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='opening_auction', full_name='vega.Market.opening_auction', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='openingAuction', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continuous', full_name='vega.Market.continuous', index=5,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continuous', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discrete', full_name='vega.Market.discrete', index=6,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='discrete', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_monitoring_settings', full_name='vega.Market.price_monitoring_settings', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='priceMonitoringSettings', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='liquidity_monitoring_parameters', full_name='vega.Market.liquidity_monitoring_parameters', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='liquidityMonitoringParameters', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trading_mode', full_name='vega.Market.trading_mode', index=9,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tradingMode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='vega.Market.state', index=10,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='state', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_timestamps', full_name='vega.Market.market_timestamps', index=11,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='marketTimestamps', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MARKET_STATE,
    _MARKET_TRADINGMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='trading_mode_config', full_name='vega.Market.trading_mode_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2898,
  serialized_end=4036,
)


_MARKETTIMESTAMPS = _descriptor.Descriptor(
  name='MarketTimestamps',
  full_name='vega.MarketTimestamps',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposed', full_name='vega.MarketTimestamps.proposed', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='proposed', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending', full_name='vega.MarketTimestamps.pending', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pending', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='vega.MarketTimestamps.open', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='open', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='vega.MarketTimestamps.close', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='close', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4038,
  serialized_end=4152,
)

_FUTURE.fields_by_name['oracle_spec'].message_type = oracles_dot_v1_dot_oracle__spec__pb2._ORACLESPEC
_FUTURE.fields_by_name['oracle_spec_binding'].message_type = _ORACLESPECTOFUTUREBINDING
_INSTRUMENT.fields_by_name['metadata'].message_type = _INSTRUMENTMETADATA
_INSTRUMENT.fields_by_name['future'].message_type = _FUTURE
_INSTRUMENT.oneofs_by_name['product'].fields.append(
  _INSTRUMENT.fields_by_name['future'])
_INSTRUMENT.fields_by_name['future'].containing_oneof = _INSTRUMENT.oneofs_by_name['product']
_LOGNORMALRISKMODEL.fields_by_name['params'].message_type = _LOGNORMALMODELPARAMS
_SIMPLERISKMODEL.fields_by_name['params'].message_type = _SIMPLEMODELPARAMS
_MARGINCALCULATOR.fields_by_name['scaling_factors'].message_type = _SCALINGFACTORS
_TRADABLEINSTRUMENT.fields_by_name['instrument'].message_type = _INSTRUMENT
_TRADABLEINSTRUMENT.fields_by_name['margin_calculator'].message_type = _MARGINCALCULATOR
_TRADABLEINSTRUMENT.fields_by_name['log_normal_risk_model'].message_type = _LOGNORMALRISKMODEL
_TRADABLEINSTRUMENT.fields_by_name['simple_risk_model'].message_type = _SIMPLERISKMODEL
_TRADABLEINSTRUMENT.oneofs_by_name['risk_model'].fields.append(
  _TRADABLEINSTRUMENT.fields_by_name['log_normal_risk_model'])
_TRADABLEINSTRUMENT.fields_by_name['log_normal_risk_model'].containing_oneof = _TRADABLEINSTRUMENT.oneofs_by_name['risk_model']
_TRADABLEINSTRUMENT.oneofs_by_name['risk_model'].fields.append(
  _TRADABLEINSTRUMENT.fields_by_name['simple_risk_model'])
_TRADABLEINSTRUMENT.fields_by_name['simple_risk_model'].containing_oneof = _TRADABLEINSTRUMENT.oneofs_by_name['risk_model']
_FEES.fields_by_name['factors'].message_type = _FEEFACTORS
_PRICEMONITORINGPARAMETERS.fields_by_name['triggers'].message_type = _PRICEMONITORINGTRIGGER
_PRICEMONITORINGSETTINGS.fields_by_name['parameters'].message_type = _PRICEMONITORINGPARAMETERS
_LIQUIDITYMONITORINGPARAMETERS.fields_by_name['target_stake_parameters'].message_type = _TARGETSTAKEPARAMETERS
_MARKET.fields_by_name['tradable_instrument'].message_type = _TRADABLEINSTRUMENT
_MARKET.fields_by_name['fees'].message_type = _FEES
_MARKET.fields_by_name['opening_auction'].message_type = _AUCTIONDURATION
_MARKET.fields_by_name['continuous'].message_type = _CONTINUOUSTRADING
_MARKET.fields_by_name['discrete'].message_type = _DISCRETETRADING
_MARKET.fields_by_name['price_monitoring_settings'].message_type = _PRICEMONITORINGSETTINGS
_MARKET.fields_by_name['liquidity_monitoring_parameters'].message_type = _LIQUIDITYMONITORINGPARAMETERS
_MARKET.fields_by_name['trading_mode'].enum_type = _MARKET_TRADINGMODE
_MARKET.fields_by_name['state'].enum_type = _MARKET_STATE
_MARKET.fields_by_name['market_timestamps'].message_type = _MARKETTIMESTAMPS
_MARKET_STATE.containing_type = _MARKET
_MARKET_TRADINGMODE.containing_type = _MARKET
_MARKET.oneofs_by_name['trading_mode_config'].fields.append(
  _MARKET.fields_by_name['continuous'])
_MARKET.fields_by_name['continuous'].containing_oneof = _MARKET.oneofs_by_name['trading_mode_config']
_MARKET.oneofs_by_name['trading_mode_config'].fields.append(
  _MARKET.fields_by_name['discrete'])
_MARKET.fields_by_name['discrete'].containing_oneof = _MARKET.oneofs_by_name['trading_mode_config']
DESCRIPTOR.message_types_by_name['AuctionDuration'] = _AUCTIONDURATION
DESCRIPTOR.message_types_by_name['ContinuousTrading'] = _CONTINUOUSTRADING
DESCRIPTOR.message_types_by_name['DiscreteTrading'] = _DISCRETETRADING
DESCRIPTOR.message_types_by_name['Future'] = _FUTURE
DESCRIPTOR.message_types_by_name['OracleSpecToFutureBinding'] = _ORACLESPECTOFUTUREBINDING
DESCRIPTOR.message_types_by_name['InstrumentMetadata'] = _INSTRUMENTMETADATA
DESCRIPTOR.message_types_by_name['Instrument'] = _INSTRUMENT
DESCRIPTOR.message_types_by_name['LogNormalRiskModel'] = _LOGNORMALRISKMODEL
DESCRIPTOR.message_types_by_name['LogNormalModelParams'] = _LOGNORMALMODELPARAMS
DESCRIPTOR.message_types_by_name['SimpleRiskModel'] = _SIMPLERISKMODEL
DESCRIPTOR.message_types_by_name['SimpleModelParams'] = _SIMPLEMODELPARAMS
DESCRIPTOR.message_types_by_name['ScalingFactors'] = _SCALINGFACTORS
DESCRIPTOR.message_types_by_name['MarginCalculator'] = _MARGINCALCULATOR
DESCRIPTOR.message_types_by_name['TradableInstrument'] = _TRADABLEINSTRUMENT
DESCRIPTOR.message_types_by_name['FeeFactors'] = _FEEFACTORS
DESCRIPTOR.message_types_by_name['Fees'] = _FEES
DESCRIPTOR.message_types_by_name['PriceMonitoringTrigger'] = _PRICEMONITORINGTRIGGER
DESCRIPTOR.message_types_by_name['PriceMonitoringParameters'] = _PRICEMONITORINGPARAMETERS
DESCRIPTOR.message_types_by_name['PriceMonitoringSettings'] = _PRICEMONITORINGSETTINGS
DESCRIPTOR.message_types_by_name['LiquidityMonitoringParameters'] = _LIQUIDITYMONITORINGPARAMETERS
DESCRIPTOR.message_types_by_name['TargetStakeParameters'] = _TARGETSTAKEPARAMETERS
DESCRIPTOR.message_types_by_name['Market'] = _MARKET
DESCRIPTOR.message_types_by_name['MarketTimestamps'] = _MARKETTIMESTAMPS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AuctionDuration = _reflection.GeneratedProtocolMessageType('AuctionDuration', (_message.Message,), {
  'DESCRIPTOR' : _AUCTIONDURATION,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.AuctionDuration)
  })
_sym_db.RegisterMessage(AuctionDuration)

ContinuousTrading = _reflection.GeneratedProtocolMessageType('ContinuousTrading', (_message.Message,), {
  'DESCRIPTOR' : _CONTINUOUSTRADING,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.ContinuousTrading)
  })
_sym_db.RegisterMessage(ContinuousTrading)

DiscreteTrading = _reflection.GeneratedProtocolMessageType('DiscreteTrading', (_message.Message,), {
  'DESCRIPTOR' : _DISCRETETRADING,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.DiscreteTrading)
  })
_sym_db.RegisterMessage(DiscreteTrading)

Future = _reflection.GeneratedProtocolMessageType('Future', (_message.Message,), {
  'DESCRIPTOR' : _FUTURE,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.Future)
  })
_sym_db.RegisterMessage(Future)

OracleSpecToFutureBinding = _reflection.GeneratedProtocolMessageType('OracleSpecToFutureBinding', (_message.Message,), {
  'DESCRIPTOR' : _ORACLESPECTOFUTUREBINDING,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.OracleSpecToFutureBinding)
  })
_sym_db.RegisterMessage(OracleSpecToFutureBinding)

InstrumentMetadata = _reflection.GeneratedProtocolMessageType('InstrumentMetadata', (_message.Message,), {
  'DESCRIPTOR' : _INSTRUMENTMETADATA,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.InstrumentMetadata)
  })
_sym_db.RegisterMessage(InstrumentMetadata)

Instrument = _reflection.GeneratedProtocolMessageType('Instrument', (_message.Message,), {
  'DESCRIPTOR' : _INSTRUMENT,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.Instrument)
  })
_sym_db.RegisterMessage(Instrument)

LogNormalRiskModel = _reflection.GeneratedProtocolMessageType('LogNormalRiskModel', (_message.Message,), {
  'DESCRIPTOR' : _LOGNORMALRISKMODEL,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.LogNormalRiskModel)
  })
_sym_db.RegisterMessage(LogNormalRiskModel)

LogNormalModelParams = _reflection.GeneratedProtocolMessageType('LogNormalModelParams', (_message.Message,), {
  'DESCRIPTOR' : _LOGNORMALMODELPARAMS,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.LogNormalModelParams)
  })
_sym_db.RegisterMessage(LogNormalModelParams)

SimpleRiskModel = _reflection.GeneratedProtocolMessageType('SimpleRiskModel', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLERISKMODEL,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.SimpleRiskModel)
  })
_sym_db.RegisterMessage(SimpleRiskModel)

SimpleModelParams = _reflection.GeneratedProtocolMessageType('SimpleModelParams', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLEMODELPARAMS,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.SimpleModelParams)
  })
_sym_db.RegisterMessage(SimpleModelParams)

ScalingFactors = _reflection.GeneratedProtocolMessageType('ScalingFactors', (_message.Message,), {
  'DESCRIPTOR' : _SCALINGFACTORS,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.ScalingFactors)
  })
_sym_db.RegisterMessage(ScalingFactors)

MarginCalculator = _reflection.GeneratedProtocolMessageType('MarginCalculator', (_message.Message,), {
  'DESCRIPTOR' : _MARGINCALCULATOR,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.MarginCalculator)
  })
_sym_db.RegisterMessage(MarginCalculator)

TradableInstrument = _reflection.GeneratedProtocolMessageType('TradableInstrument', (_message.Message,), {
  'DESCRIPTOR' : _TRADABLEINSTRUMENT,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.TradableInstrument)
  })
_sym_db.RegisterMessage(TradableInstrument)

FeeFactors = _reflection.GeneratedProtocolMessageType('FeeFactors', (_message.Message,), {
  'DESCRIPTOR' : _FEEFACTORS,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.FeeFactors)
  })
_sym_db.RegisterMessage(FeeFactors)

Fees = _reflection.GeneratedProtocolMessageType('Fees', (_message.Message,), {
  'DESCRIPTOR' : _FEES,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.Fees)
  })
_sym_db.RegisterMessage(Fees)

PriceMonitoringTrigger = _reflection.GeneratedProtocolMessageType('PriceMonitoringTrigger', (_message.Message,), {
  'DESCRIPTOR' : _PRICEMONITORINGTRIGGER,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.PriceMonitoringTrigger)
  })
_sym_db.RegisterMessage(PriceMonitoringTrigger)

PriceMonitoringParameters = _reflection.GeneratedProtocolMessageType('PriceMonitoringParameters', (_message.Message,), {
  'DESCRIPTOR' : _PRICEMONITORINGPARAMETERS,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.PriceMonitoringParameters)
  })
_sym_db.RegisterMessage(PriceMonitoringParameters)

PriceMonitoringSettings = _reflection.GeneratedProtocolMessageType('PriceMonitoringSettings', (_message.Message,), {
  'DESCRIPTOR' : _PRICEMONITORINGSETTINGS,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.PriceMonitoringSettings)
  })
_sym_db.RegisterMessage(PriceMonitoringSettings)

LiquidityMonitoringParameters = _reflection.GeneratedProtocolMessageType('LiquidityMonitoringParameters', (_message.Message,), {
  'DESCRIPTOR' : _LIQUIDITYMONITORINGPARAMETERS,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.LiquidityMonitoringParameters)
  })
_sym_db.RegisterMessage(LiquidityMonitoringParameters)

TargetStakeParameters = _reflection.GeneratedProtocolMessageType('TargetStakeParameters', (_message.Message,), {
  'DESCRIPTOR' : _TARGETSTAKEPARAMETERS,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.TargetStakeParameters)
  })
_sym_db.RegisterMessage(TargetStakeParameters)

Market = _reflection.GeneratedProtocolMessageType('Market', (_message.Message,), {
  'DESCRIPTOR' : _MARKET,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.Market)
  })
_sym_db.RegisterMessage(Market)

MarketTimestamps = _reflection.GeneratedProtocolMessageType('MarketTimestamps', (_message.Message,), {
  'DESCRIPTOR' : _MARKETTIMESTAMPS,
  '__module__' : 'markets_pb2'
  # @@protoc_insertion_point(class_scope:vega.MarketTimestamps)
  })
_sym_db.RegisterMessage(MarketTimestamps)


DESCRIPTOR._options = None
_DISCRETETRADING.fields_by_name['duration_ns']._options = None
_SIMPLEMODELPARAMS.fields_by_name['max_move_up']._options = None
_SIMPLEMODELPARAMS.fields_by_name['min_move_down']._options = None
_SIMPLEMODELPARAMS.fields_by_name['probability_of_trading']._options = None
_PRICEMONITORINGTRIGGER.fields_by_name['horizon']._options = None
_PRICEMONITORINGTRIGGER.fields_by_name['probability']._options = None
_PRICEMONITORINGTRIGGER.fields_by_name['auction_extension']._options = None
_LIQUIDITYMONITORINGPARAMETERS.fields_by_name['triggering_ratio']._options = None
_TARGETSTAKEPARAMETERS.fields_by_name['time_window']._options = None
_TARGETSTAKEPARAMETERS.fields_by_name['scaling_factor']._options = None
# @@protoc_insertion_point(module_scope)



# See vega repo, blockchain/command.go
import enum


class CommandByte(enum.Enum):
    SubmitOrder = b"\x40"
    CancelOrder = b"\x41"
    AmendOrder = b"\x42"
    Withdraw = b"\x44"
    Propose = b"\x45"
    Vote = b"\x46"
    RegisterNode = b"\x47"
    NodeVote = b"\x48"
    NodeSignature = b"\x49"

    ChainEvent = b"\x50"


class CommandString(enum.Enum):
    SubmitOrder = "Submit Order"
    CancelOrder = "Cancel Order"
    AmendOrder = "Amend Order"
    Withdraw = "Withdraw"
    Propose = "Proposal"
    Vote = "Vote on Proposal"
    RegisterNode = "Register new Node"
    NodeVote = "Node Vote"
    NodeSignature = "Node Signature"

    ChainEvent = "Chain Event"



import base64
import uuid
from google.protobuf.empty_pb2 import Empty

import vegaapiclient as vac

from .fixtures import (  # noqa: F401
    trading,
    tradingdata,
    walletclient,
    walletClientWalletKeypair,
    walletname,
    walletpassphrase,
)
from .helpers import check_response


def test_SubmitOrder(
    trading, tradingdata, walletClientWalletKeypair  # noqa: F811
):
    (walletclient, _, _, pubKey) = walletClientWalletKeypair  # noqa: F811

    # Get a market
    req = vac.api.trading.MarketByIDRequest(market_id="076BB86A5AA41E3E")
    market = tradingdata.MarketByID(req).market

    # Prepare the SubmitOrder
    now = int(tradingdata.GetVegaTime(Empty()).timestamp)
    request = vac.api.trading.PrepareSubmitOrderRequest(
        submission=vac.vega.OrderSubmission(
            expires_at=now + 120000000000,
            market_id=market.id,
            party_id=pubKey,
            price=10,
            side=vac.vega.Side.SIDE_BUY,
            size=1,
            time_in_force=vac.vega.Order.TimeInForce.TIME_IN_FORCE_GTT,
            type=vac.vega.Order.Type.TYPE_LIMIT,
            reference=str(uuid.uuid4()),
        )
    )
    # Either: Prepare the SubmitOrder using the Vega node
    # blob = trading.PrepareSubmitOrder(request, contact_node=True).blob
    # Or: Prepare the SubmitOrder ourselves
    blob = trading.PrepareSubmitOrder(request, contact_node=False).blob

    # Sign the tx
    r = walletclient.signtx(
        base64.b64encode(blob).decode("ascii"), pubKey, False
    )
    check_response(r)
    signedTx = r.json()["signedTx"]

    # Submit the signed transaction
    # assert blob == base64.b64decode(signedTx["data"])
    request = vac.api.trading.SubmitTransactionRequest(
        tx=vac.vega.SignedBundle(
            tx=base64.b64decode(signedTx["tx"]),
            sig=vac.vega.Signature(
                sig=base64.b64decode(signedTx["sig"]["sig"]),
                algo=signedTx["sig"]["algo"],
                version=signedTx["sig"]["version"],
            ),
        )
    )
    response = trading.SubmitTransaction(request)
    assert response.success
